@@ -19,7 +19,7 @@ class VersionsSchema(Schema):
 
     is_latest = fields.Boolean()
     is_latest_draft = fields.Boolean()
-    parent_index = fields.Integer()
+    index = fields.Integer()
 
 
 class ParentSchema(Schema):
