@@ -7,9 +7,9 @@ from invenio_drafts_resources.records.api import Draft as DraftBase
 from invenio_drafts_resources.records.api import \
     ParentRecord as ParentRecordBase
 from invenio_drafts_resources.records.api import Record as RecordBase
-from invenio_drafts_resources.records.systemfields import ParentField
 
-from .models import DraftMetadata, ParentRecordMetadata, RecordMetadata
+from .models import DraftMetadata, ParentRecordMetadata, ParentState, \
+    RecordMetadata
 
 
 class ParentRecord(ParentRecordBase):
@@ -28,6 +28,8 @@ class Record(RecordBase):
 
     # Configuration
     model_cls = RecordMetadata
+    versions_model_cls = ParentState
+    parent_record_cls = ParentRecord
 
     # System fields
     schema = ConstantField(
@@ -38,19 +40,14 @@ class Record(RecordBase):
         search_alias='draftsresources-records'
     )
 
-    parent = ParentField(
-        ParentRecord, create=False, soft_delete=False, hard_delete=False)
-
-    create_from_draft = [
-        'parent'
-    ]
-
 
 class Draft(DraftBase):
     """Example record API."""
 
     # Configuration
     model_cls = DraftMetadata
+    versions_model_cls = ParentState
+    parent_record_cls = ParentRecord
 
     # System fields
     schema = ConstantField(
@@ -60,6 +57,3 @@ class Draft(DraftBase):
         'draftsresources-drafts-draft-v1.0.0',
         search_alias='draftsresources-drafts'
     )
-
-    parent = ParentField(
-        ParentRecord, create=True, soft_delete=False, hard_delete=True)
